# -*- encoding: utf-8 -*-
require 'spec_helper'

describe Speech do
  before do
    FactoryGirl.create :admin
    @sp = FactoryGirl.create :system_picture
    @lg = FactoryGirl.create :license_group
    @l = FactoryGirl.create :license, :license_group_id => @lg.id, :system_picture_id => @sp.id
    @user = FactoryGirl.create( :user_yas)
    @author = @user.author
    
    @panel = FactoryGirl.create :panel
    @speech_balloon_template = FactoryGirl.create :speech_balloon_template
    @speech_balloon = FactoryGirl.create :speech_balloon, :panel_id => @panel.id, :speech_balloon_template_id => @speech_balloon_template.id
  end
  
  describe '検証に於いて' do
    before do
      @speech = FactoryGirl.build :speech, :speech_balloon_id => @speech_balloon.id
    end
    
    context 'オーソドックスなデータのとき' do
      it '下限データが通る' do
        @speech.x = 0
        @speech.y = 0
        @speech.width = 1
        @speech.height = 1
        @speech.should be_valid
      end
      it '上限データが通る' do
        @speech.x = 99999
        @speech.y = 99999
        @speech.width = 99999
        @speech.height = 99999
        @speech.should be_valid
      end
    end
    
    context 'speech_balloon_idを検証するとき' do
      #ネストの保存はnilを許可しなければならないので数値チェックだけ
      it 'テストデータの確認' do
        @speech.speech_balloon_id = @speech_balloon.id
        @speech.should be_valid
      end
      it '数値でなければ失敗する' do
        @speech.speech_balloon_id = 'a'
        @speech.should_not be_valid
      end
    end
    context 'contentを検証するとき' do
    end
    context 'xを検証するとき' do
      it 'nullなら失敗する' do
        @speech.x = nil
        @speech.should_not be_valid
      end
      it '数値でなければ失敗する' do
        @speech.x = 'a'
        @speech.should_not be_valid
      end
      it '0なら通る' do
        @speech.x = '0'
        @speech.should be_valid
      end
      it '負でも通る' do
        @speech.x = -1
        @speech.should be_valid
      end
    end
    context 'yを検証するとき' do
      it 'nullなら失敗する' do
        @speech.y = nil
        @speech.should_not be_valid
      end
      it '数値でなければ失敗する' do
        @speech.y = 'a'
        @speech.should_not be_valid
      end
      it '0なら通る' do
        @speech.y = '0'
        @speech.should be_valid
      end
      it '負でも通る' do
        @speech.y = -1
        @speech.should be_valid
      end
    end
    context 'widthを検証するとき' do
      it 'nullなら失敗する' do
        @speech.width = nil
        @speech.should_not be_valid
      end
      it '数値でなければ失敗する' do
        @speech.width = 'a'
        @speech.should_not be_valid
      end
      it '0なら失敗する' do
        @speech.width = '0'
        @speech.should_not be_valid
      end
      it '負でも失敗する' do
        @speech.width = -1
        @speech.should_not be_valid
      end
    end
    context 'heightを検証するとき' do
      it 'nullなら失敗する' do
        @speech.height = nil
        @speech.should_not be_valid
      end
      it '数値でなければ失敗する' do
        @speech.height = 'a'
        @speech.should_not be_valid
      end
      it '0なら失敗する' do
        @speech.height = '0'
        @speech.should_not be_valid
      end
      it '負でも失敗する' do
        @speech.height = -1
        @speech.should_not be_valid
      end
    end
    context 'settingsを検証するとき' do
    end
  end
  
end
